@@ -1,3 +1,11 @@
+.onLoad <- function(lib, pkg) {require(methods); require(setRNG)}
+
+setGeneric("log", function(x, base) standardGeneric("log"), group = "Math")
+setGeneric("log10", function(x) standardGeneric("log10"), group = "Math")
+setGeneric("gamma", function(x) standardGeneric("gamma"), group = "Math")
+setGeneric("lgamma", function(x) standardGeneric("lgamma"), group = "Math")
+
+
 DefaultNrGridPoints <- 2^12
 DistrResolution <- 1e-6
 TruncQuantile <- 1e-5
